@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010008";
+    our $MITE_VERSION = "0.013000";
 
     # Mite keywords
     BEGIN {
@@ -47,10 +47,12 @@
         *false   = \&Sub::HandlesVia::Mite::false;
         *guard   = \&Sub::HandlesVia::Mite::guard;
         *lazy    = \&Sub::HandlesVia::Mite::lazy;
+        *lock    = \&Sub::HandlesVia::Mite::lock;
         *ro      = \&Sub::HandlesVia::Mite::ro;
         *rw      = \&Sub::HandlesVia::Mite::rw;
         *rwp     = \&Sub::HandlesVia::Mite::rwp;
         *true    = \&Sub::HandlesVia::Mite::true;
+        *unlock  = \&Sub::HandlesVia::Mite::unlock;
     }
 
     # Gather metadata for constructor and destructor
@@ -65,8 +67,8 @@
                 map { "$_\::BUILD" } reverse @$linear_isa
             ],
             DEMOLISH => [
-                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } @$linear_isa
+                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+                map { "$_\::DEMOLISH" } @$linear_isa
             ],
             HAS_BUILDARGS        => $class->can('BUILDARGS'),
             HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
@@ -273,7 +275,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -285,7 +287,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -305,7 +307,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -317,7 +319,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -337,7 +339,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -349,7 +351,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -373,7 +375,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -385,7 +387,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -409,7 +411,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -421,7 +423,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -699,7 +701,7 @@
                         (
                             (
                                 !ref $to_coerce
-                                  and (!defined $to_coerce
+                                  and ( !defined $to_coerce
                                     or $to_coerce eq q()
                                     or $to_coerce eq '0'
                                     or $to_coerce eq '1' )
@@ -711,7 +713,7 @@
                     };
                     (
                         !ref $default_value
-                          and (!defined $default_value
+                          and ( !defined $default_value
                             or $default_value eq q()
                             or $default_value eq '0'
                             or $default_value eq '1' )
@@ -938,7 +940,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010008";
+    our $MITE_VERSION = "0.013000";
 
     # Mite keywords
     BEGIN {
@@ -978,10 +980,12 @@
         *false   = \&Sub::HandlesVia::Mite::false;
         *guard   = \&Sub::HandlesVia::Mite::guard;
         *lazy    = \&Sub::HandlesVia::Mite::lazy;
+        *lock    = \&Sub::HandlesVia::Mite::lock;
         *ro      = \&Sub::HandlesVia::Mite::ro;
         *rw      = \&Sub::HandlesVia::Mite::rw;
         *rwp     = \&Sub::HandlesVia::Mite::rwp;
         *true    = \&Sub::HandlesVia::Mite::true;
+        *unlock  = \&Sub::HandlesVia::Mite::unlock;
     }
 
     BEGIN {
@@ -1175,7 +1179,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1187,7 +1191,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1207,7 +1211,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1219,7 +1223,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1239,7 +1243,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1251,7 +1255,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1275,7 +1279,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1287,7 +1291,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1311,7 +1315,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1323,7 +1327,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1488,7 +1492,7 @@
 
     our $USES_MITE    = "Mite::Class";
     our $MITE_SHIM    = "Sub::HandlesVia::Mite";
-    our $MITE_VERSION = "0.010008";
+    our $MITE_VERSION = "0.013000";
 
     # Mite keywords
     BEGIN {
@@ -1528,10 +1532,12 @@
         *false   = \&Sub::HandlesVia::Mite::false;
         *guard   = \&Sub::HandlesVia::Mite::guard;
         *lazy    = \&Sub::HandlesVia::Mite::lazy;
+        *lock    = \&Sub::HandlesVia::Mite::lock;
         *ro      = \&Sub::HandlesVia::Mite::ro;
         *rw      = \&Sub::HandlesVia::Mite::rw;
         *rwp     = \&Sub::HandlesVia::Mite::rwp;
         *true    = \&Sub::HandlesVia::Mite::true;
+        *unlock  = \&Sub::HandlesVia::Mite::unlock;
     }
 
     BEGIN {
@@ -1741,7 +1747,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1753,7 +1759,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1773,7 +1779,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1785,7 +1791,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1805,7 +1811,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1817,7 +1823,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1841,7 +1847,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1853,7 +1859,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
@@ -1877,7 +1883,7 @@
                     (
                         (
                             !ref $to_coerce
-                              and (!defined $to_coerce
+                              and ( !defined $to_coerce
                                 or $to_coerce eq q()
                                 or $to_coerce eq '0'
                                 or $to_coerce eq '1' )
@@ -1889,7 +1895,7 @@
                 };
                 (
                     !ref $coerced_value
-                      and (!defined $coerced_value
+                      and ( !defined $coerced_value
                         or $coerced_value eq q()
                         or $coerced_value eq '0'
                         or $coerced_value eq '1' )
