@@ -2,16 +2,49 @@
 package MyTest::Class1;
 use strict;
 use warnings;
+no warnings qw( once void );
 
 our $USES_MITE = "Mite::Class";
 our $MITE_SHIM = "MyTest::Mite";
-our $MITE_VERSION = "0.009000";
-
+our $MITE_VERSION = "0.010008";
+# Mite keywords
 BEGIN {
-    require MyTest::Role2;
-    our %DOES = ( "MyTest::Class1" => 1, "MyTest::Role2" => 1, "MyTest::Role1" => 1 );
+    my ( $SHIM, $CALLER ) = ( "MyTest::Mite", "MyTest::Class1" );
+    ( *after, *around, *before, *extends, *has, *signature_for, *with ) = do {
+        package MyTest::Mite;
+        no warnings 'redefine';
+        (
+            sub { $SHIM->HANDLE_after( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_around( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_before( $CALLER, "class", @_ ) },
+            sub {},
+            sub { $SHIM->HANDLE_has( $CALLER, has => @_ ) },
+            sub { $SHIM->HANDLE_signature_for( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_with( $CALLER, @_ ) },
+        );
+    };
+};
+
+# Gather metadata for constructor and destructor
+sub __META__ {
+    no strict 'refs';
+    my $class      = shift; $class = ref($class) || $class;
+    my $linear_isa = mro::get_linear_isa( $class );
+    return {
+        BUILD => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::BUILD" } reverse @$linear_isa
+        ],
+        DEMOLISH => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::DEMOLISH" } @$linear_isa
+        ],
+        HAS_BUILDARGS => $class->can('BUILDARGS'),
+        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
+    };
 }
 
+
 # Standard Moose/Moo-style constructor
 sub new {
     my $class = ref($_[0]) ? ref(shift) : shift;
@@ -21,7 +54,7 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Attribute list (type: ArrayRef)
-    # has declaration, file lib/MyTest/Role1.pm, line 41
+    # has declaration, file lib/MyTest/Role1.pm, line 42
     do { my $value = exists( $args->{"list"} ) ? $args->{"list"} : $MyTest::Role1::__list_DEFAULT__->( $self ); (ref($value) eq 'ARRAY') or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "list", "ArrayRef"; $self->{"list"} = $value; }; 
 
 
@@ -61,44 +94,10 @@ sub DESTROY {
     return;
 }
 
-# Gather metadata for constructor and destructor
-sub __META__ {
-    no strict 'refs';
-    no warnings 'once';
-    my $class      = shift; $class = ref($class) || $class;
-    my $linear_isa = mro::get_linear_isa( $class );
-    return {
-        BUILD => [
-            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-            map { "$_\::BUILD" } reverse @$linear_isa
-        ],
-        DEMOLISH => [
-            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-            map { "$_\::DEMOLISH" } @$linear_isa
-        ],
-        HAS_BUILDARGS => $class->can('BUILDARGS'),
-        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
-    };
-}
-
-# See UNIVERSAL
-sub DOES {
-    my ( $self, $role ) = @_;
-    our %DOES;
-    return $DOES{$role} if exists $DOES{$role};
-    return 1 if $role eq __PACKAGE__;
-    return $self->SUPER::DOES( $role );
-}
-
-# Alias for Moose/Moo-compatibility
-sub does {
-    shift->DOES( @_ );
-}
-
-my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
+my $__XS = !$ENV{PERL_ONLY} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for list
-# has declaration, file lib/MyTest/Role1.pm, line 41
+# has declaration, file lib/MyTest/Role1.pm, line 42
 if ( $__XS ) {
     Class::XSAccessor->import(
         chained => 1,
@@ -110,5 +109,28 @@ else {
 }
 
 
+BEGIN {
+    require MyTest::Role2;
+    
+    our %DOES = ( "MyTest::Class1" => 1, "MyTest::Role2" => 1, "MyTest::Role1" => 1 );
+}
+
+# See UNIVERSAL
+sub DOES {
+    my ( $self, $role ) = @_;
+    our %DOES;
+    return $DOES{$role} if exists $DOES{$role};
+    return 1 if $role eq __PACKAGE__;
+    if ( $INC{'Moose/Util.pm'} and my $meta = Moose::Util::find_meta( ref $self or $self ) ) {
+        $meta->can( 'does_role' ) and $meta->does_role( $role ) and return 1;
+    }
+    return $self->SUPER::DOES( $role );
+}
+
+# Alias for Moose/Moo-compatibility
+sub does {
+    shift->DOES( @_ );
+}
+
 1;
 }
\ No newline at end of file
